@@ -15,9 +15,15 @@ class SmartAppConfig(AppConfig):
 
         return self._rds_ca
 
+def isClowderEnabled ():
+    return bool(os.environ.get("ACG_CONFIG", False))
+
 def loadConfig(filename):
-    with open(filename) as f:
-        data = json.load(f)
+    if not filename:
+        data = {}
+    else:
+        with open(filename) as f:
+            data = json.load(f)
     return SmartAppConfig.dictToObject(data)
 
 LoadedConfig = loadConfig(os.environ.get("ACG_CONFIG"))
